==> wawa-proxy-api-0.0.9-20171204.103010-92-sources.jar: cn/com/wawa/proxy/api/code/HEncoder.java <==
package cn.com.wawa.proxy.api.code;

import org.apache.mina.core.buffer.IoBuffer;
import org.apache.mina.core.session.IoSession;
import org.apache.mina.filter.codec.ProtocolEncoder;
import org.apache.mina.filter.codec.ProtocolEncoderAdapter;
import org.apache.mina.filter.codec.ProtocolEncoderOutput;
import org.apache.mina.filter.codec.prefixedstring.PrefixedStringEncoder;

import java.io.NotSerializableException;
import java.io.Serializable;
import java.nio.charset.Charset;
import java.nio.charset.CharsetEncoder;

/**
 * Created by danke on 2017/11/14.
 */
public class HEncoder extends ProtocolEncoderAdapter {

    private final Charset charset;

    public HEncoder(Charset charset) {
        this.charset = charset;
    }

    @Override
    public void encode(IoSession session, Object message,
                       ProtocolEncoderOutput out) throws Exception {
        StringBuilder sb = new StringBuilder();
        CharsetEncoder ce = charset.newEncoder();
        IoBuffer buffer = IoBuffer.allocate(message.toString().length()).setAutoExpand(true);
        String messageStr = message.toString();
        //这边拼接完整消息长度
        int msgLength = messageStr.getBytes().length;
        switch (String.valueOf(msgLength).length()){//前4位为长度
            case 1:
                sb.append("000"+msgLength);
                break;
            case 2:
                sb.append("00"+msgLength);
                break;
            case 3:
                sb.append("0"+msgLength);
                break;
            case 4:
                sb.append(String.valueOf(msgLength));
                break;
            default:
                return;
        }
        sb.append(messageStr);
        buffer.putString(sb.toString(),ce);
        buffer.flip();
        out.write(buffer);
    }
}

==> wawa-proxy-api-0.0.9-20171205.035915-97-sources.jar: cn/com/wawa/proxy/api/code/HEncoder.java <==
package cn.com.wawa.proxy.api.code;

import org.apache.mina.core.buffer.IoBuffer;
import org.apache.mina.core.session.IoSession;
import org.apache.mina.filter.codec.ProtocolEncoder;
import org.apache.mina.filter.codec.ProtocolEncoderAdapter;
import org.apache.mina.filter.codec.ProtocolEncoderOutput;
import org.apache.mina.filter.codec.prefixedstring.PrefixedStringEncoder;

import java.io.NotSerializableException;
import java.io.Serializable;
import java.nio.charset.Charset;
import java.nio.charset.CharsetEncoder;

/**
 * Created by danke on 2017/11/14.
 */
public class HEncoder extends ProtocolEncoderAdapter {

    private final Charset charset;

    public HEncoder(Charset charset) {
        this.charset = charset;
    }

    @Override
    public void encode(IoSession session, Object message,
                       ProtocolEncoderOutput out) throws Exception {
        StringBuilder sb = new StringBuilder();
        CharsetEncoder ce = charset.newEncoder();
        IoBuffer buffer = IoBuffer.allocate(message.toString().length()).setAutoExpand(true);
        String messageStr = message.toString();
        //截取版本号
        String version = messageStr.substring(0,2);
        String messageTrue = messageStr.substring(2);
        //这边拼接完整消息长度
        int msgLength = messageTrue.getBytes().length;
        sb.append(version);
        switch (String.valueOf(msgLength).length()){//前4位为长度
            case 1:
                sb.append("000"+msgLength);
                break;
            case 2:
                sb.append("00"+msgLength);
                break;
            case 3:
                sb.append("0"+msgLength);
                break;
            case 4:
                sb.append(String.valueOf(msgLength));
                break;
            default:
                return;
        }
        sb.append(messageTrue);
        buffer.putString(sb.toString(),ce);
        buffer.flip();
        out.write(buffer);
    }
}
